###################################
# Media Coverage of Trump: NYT, WSJ
# Read, format newspaper articles
# Michele Claibourn
# February 21, 2017
##################################

#####################
# Loading libraries
# Setting directories
#####################
# install.packages("tm")
# install.packages("quanteda")
# install.packages("tm.plugin.factiva")

rm(list=ls())
library(tm)
library(tm.plugin.factiva)
library(quanteda)
library(dplyr)

# Point to path for html files
setwd("~/Box Sync/mpc/DataServices/dataForDemocracy/newspaper/factiva/")


##########################
# Read in the article text
# using tm.plugin (and tm)
##########################
nyfiles <- DirSource(pattern=".htm")

# Function to read article files and turn into a corpus
readmyfiles <- function(x){
  source <- FactivaSource(x)
  Corpus(source)
}

corpus <- lapply(nyfiles$filelist, readmyfiles) 
corpus <- do.call(c, corpus)
# do.call is a shortcut for this (calling c() on each element in the list)
# corpus <- c(corpus[[1]], corpus[[2]], corpus[[3]], corpus[[4]], corpus[[5]])

# What's in corpus
corpus
corpus[[1]][1]
meta(corpus[[1]])

meta(corpus, "origin")
meta(corpus, "pub") <- ifelse(meta(corpus, "origin")=="The New York Times", "NYT", "WSJ")
# Remove Factiva line from WSJ articles (discovered in later exploration): 
# e.g., "License this article from Dow Jones Reprint Service[http://www.djreprints.com/link/DJRFactiva.html?FACTIVA=wjco20170123000044]"
corpus <- tm_map(corpus, content_transformer(function(x) gsub("License this article from Dow Jones Reprint Service\\[[[:print:]]+\\]", "", x)))
# Replace U.S. with United States for later bigram analysis
corpus <- tm_map(corpus, content_transformer(function(x) gsub("U.S.", "United States", x)))
# Replace "---" with null (causes problems for readability in WSJ "roundup"-style pieces, where items are separated by ---)
corpus <- tm_map(corpus, content_transformer(function(x) gsub("---", "", x)))

#################################
# Turn it into a quanteda corpus
# and assign metadata
#################################
qcorpus <- corpus(corpus) # note corpus is from quanteda, Corpus is from tm
docvars(qcorpus, "pub") <- meta(corpus, "pub")
summary(qcorpus, showmeta=TRUE)

# Save
save.image("newspaper.Rdata")
